@@ -27,8 +27,7 @@ ARCHIVE_ENDPOINT_URL = env.get("ARCHIVE_ENDPOINT_URL")
 ARCHIVE_TYPE = env.get("ARCHIVE_TYPE", "file")
 ARCHIVE_BUCKET = env.get("ARCHIVE_BUCKET")
 ARCHIVE_PATH = env.get("ARCHIVE_PATH")
-PUBLICATION_BUCKET = env.get("PUBLICATION_BUCKET")
-PUBLICATION_PATH = env.get("PUBLICATION_PATH")
+PUBLICATION_BUCKET = env.get("PUBLICATION_BUCKET", ARCHIVE_BUCKET)
 
 # Logging
 LOG_FORMAT = env.get("LOG_FORMAT", "TEXT")  # options are: TEXT or JSON
